from marshmallow import Schema, fields


class TestingFieldsSchema(Schema):
    integer = fields.Integer()
    float = fields.Float()
    boolean = fields.Boolean()
    datetime = fields.DateTime()
    timedelta = fields.TimeDelta()
    dictionary = fields.Dict()
    url = fields.Url()
    email = fields.Email()


class TestingSchema(Schema):
    hug_types_number = fields.Integer()
    hug_types_greater_than_5 = fields.Integer()
    hug_types_in_range_1_5 = fields.Integer()



from aiohttp import web
import pytest

from aiohug.arguments import get_arg


def test_get_request():
    req = "message_that_should_be_the_same"
    assert get_arg(req, "request") is req


@pytest.mark.skip()
def test_directive():
    assert False


@pytest.mark.skip()
def test_arg_from_path():
    assert False


@pytest.mark.skip()
def test_arg_from_query():
    assert False


@pytest.mark.skip()
def test_order():
    assert False


@pytest.mark.skip()
def test_return_default():
    assert False
